@@ -1,14 +1,15 @@
+from typing import Optional
+
 from mitmproxy.contrib.wbxml import ASCommandResponse
 from . import base
 
 
 class ViewWBXML(base.View):
     name = "WBXML"
-    prompt = ("wbxml", "w")
-    content_types = [
+    __content_types = (
         "application/vnd.wap.wbxml",
         "application/vnd.ms-sync.wbxml"
-    ]
+    )
 
     def __call__(self, data, **metadata):
         try:
@@ -18,3 +19,6 @@ class ViewWBXML(base.View):
                 return "WBXML", base.format_text(parsedContent)
         except:
             return None
+
+    def render_priority(self, data: bytes, *, content_type: Optional[str] = None, **metadata) -> float:
+        return float(content_type in self.__content_types)
