@@ -1,8 +1,6 @@
 from typing import Optional, Sequence
 
 from mitmproxy import optmanager
-from mitmproxy.net import tls
-
 
 CONF_DIR = "~/.mitmproxy"
 CONF_BASENAME = "mitmproxy"
@@ -47,6 +45,15 @@ class Options(optmanager.OptManager):
             certificate as the first entry.
             """
         )
+        self.add_option(
+            "cert_passphrase", Optional[str], None,
+            """
+            Passphrase for decrypting the private key provided in the --cert option.
+
+            Note that passing cert_passphrase on the command line makes your passphrase visible in your system's
+            process list. Specify it in config.yaml to avoid this.
+            """
+        )
         self.add_option(
             "ciphers_client", Optional[str], None,
             "Set supported ciphers for client connections using OpenSSL syntax."
@@ -81,10 +88,6 @@ class Options(optmanager.OptManager):
             "listen_port", int, LISTEN_PORT,
             "Proxy service port."
         )
-        self.add_option(
-            "upstream_bind_address", str, "",
-            "Address to bind upstream requests to."
-        )
         self.add_option(
             "mode", str, "regular",
             """
@@ -103,47 +106,15 @@ class Options(optmanager.OptManager):
             "Enable/disable HTTP/2 support. "
             "HTTP/2 support is enabled by default.",
         )
-        self.add_option(
-            "http2_priority", bool, False,
-            """
-            PRIORITY forwarding for HTTP/2 connections. Disabled by default to ensure compatibility
-            with misbehaving servers.
-            """
-        )
         self.add_option(
             "websocket", bool, True,
             "Enable/disable WebSocket support. "
             "WebSocket support is enabled by default.",
         )
         self.add_option(
-            "rawtcp", bool, False,
-            "Enable/disable experimental raw TCP support. TCP connections starting with non-ascii "
-            "bytes are treated as if they would match tcp_hosts. The heuristic is very rough, use "
-            "with caution. Disabled by default. "
-        )
-
-        self.add_option(
-            "spoof_source_address", bool, False,
-            """
-            Use the client's IP for server-side connections. Combine with
-            --upstream-bind-address to spoof a fixed source address.
-            """
-        )
-        self.add_option(
-            "ssl_version_client", str, "secure",
-            """
-            Set supported SSL/TLS versions for client connections. SSLv2, SSLv3
-            and 'all' are INSECURE. Defaults to secure, which is TLS1.0+.
-            """,
-            choices=list(tls.VERSION_CHOICES.keys()),
-        )
-        self.add_option(
-            "ssl_version_server", str, "secure",
-            """
-            Set supported SSL/TLS versions for server connections. SSLv2, SSLv3
-            and 'all' are INSECURE. Defaults to secure, which is TLS1.0+.
-            """,
-            choices=list(tls.VERSION_CHOICES.keys()),
+            "rawtcp", bool, True,
+            "Enable/disable raw TCP connections. "
+            "TCP connections are enabled by default. "
         )
         self.add_option(
             "ssl_insecure", bool, False,
@@ -164,8 +135,8 @@ class Options(optmanager.OptManager):
             "tcp_hosts", Sequence[str], [],
             """
             Generic TCP SSL proxy mode for all hosts that match the pattern.
-            Similar to --ignore, but SSL connections are intercepted. The
-            communication contents are printed to the log in verbose mode.
+            Similar to --ignore-hosts, but SSL connections are intercepted.
+            The communication contents are printed to the log in verbose mode.
             """
         )
         self.add_option(
