@@ -3,7 +3,7 @@ This module provides a @concurrent decorator primitive to
 offload computations from mitmproxy's main master thread.
 """
 
-from mitmproxy import eventsequence
+from mitmproxy import hooks
 from mitmproxy.coretypes import basethread
 
 
@@ -12,7 +12,7 @@ class ScriptThread(basethread.BaseThread):
 
 
 def concurrent(fn):
-    if fn.__name__ not in eventsequence.Events - {"load", "configure"}:
+    if fn.__name__ not in set(hooks.all_hooks.keys()) - {"load", "configure"}:
         raise NotImplementedError(
             "Concurrent decorator not supported for '%s' method." % fn.__name__
         )
@@ -26,12 +26,10 @@ def concurrent(fn):
         def run():
             fn(*args)
             if obj.reply.state == "taken":
-                if not obj.reply.has_message:
-                    obj.reply.ack()
                 obj.reply.commit()
         obj.reply.take()
         ScriptThread(
-            "script.concurrent (%s)" % fn.__name__,
+            f"script.concurrent {fn.__name__}",
             target=run
         ).start()
 
