@@ -1,15 +1,12 @@
-import io
 import uuid
 
-from mitmproxy.test import tutils
+from mitmproxy import connection
+from mitmproxy import controller
+from mitmproxy import flow
+from mitmproxy import http
 from mitmproxy import tcp
 from mitmproxy import websocket
-from mitmproxy import controller
-from mitmproxy import http
-from mitmproxy import flow
-from mitmproxy.net import http as net_http
-from mitmproxy.utils import compat
-
+from mitmproxy.test.tutils import treq, tresp
 from wsproto.frame_protocol import Opcode
 
 
@@ -33,77 +30,73 @@ def ttcpflow(client_conn=True, server_conn=True, messages=True, err=None):
     return f
 
 
-def twebsocketflow(client_conn=True, server_conn=True, messages=True, err=None, handshake_flow=True):
+def twebsocketflow(messages=True, err=None, close_code=None, close_reason='') -> http.HTTPFlow:
+    flow = http.HTTPFlow(tclient_conn(), tserver_conn())
+    flow.request = http.Request(
+        "example.com",
+        80,
+        b"GET",
+        b"http",
+        b"example.com",
+        b"/ws",
+        b"HTTP/1.1",
+        headers=http.Headers(
+            connection="upgrade",
+            upgrade="websocket",
+            sec_websocket_version="13",
+            sec_websocket_key="1234",
+        ),
+        content=b'',
+        trailers=None,
+        timestamp_start=946681200,
+        timestamp_end=946681201,
 
-    if client_conn is True:
-        client_conn = tclient_conn()
-    if server_conn is True:
-        server_conn = tserver_conn()
-    if handshake_flow is True:
-        req = http.HTTPRequest(
-            "example.com",
-            80,
-            b"GET",
-            b"http",
-            b"example.com",
-            b"/ws",
-            b"HTTP/1.1",
-            headers=net_http.Headers(
-                connection="upgrade",
-                upgrade="websocket",
-                sec_websocket_version="13",
-                sec_websocket_key="1234",
-            ),
-            content=b'',
-            trailers=None,
-            timestamp_start=946681200,
-            timestamp_end=946681201,
-
-        )
-        resp = http.HTTPResponse(
-            b"HTTP/1.1",
-            101,
-            reason=net_http.status_codes.RESPONSES.get(101),
-            headers=net_http.Headers(
-                connection='upgrade',
-                upgrade='websocket',
-                sec_websocket_accept=b'',
-            ),
-            content=b'',
-            trailers=None,
-            timestamp_start=946681202,
-            timestamp_end=946681203,
-        )
-        handshake_flow = http.HTTPFlow(client_conn, server_conn)
-        handshake_flow.request = req
-        handshake_flow.response = resp
-
-    f = websocket.WebSocketFlow(client_conn, server_conn, handshake_flow)
-    f.metadata['websocket_handshake'] = handshake_flow.id
-    handshake_flow.metadata['websocket_flow'] = f.id
-    handshake_flow.metadata['websocket'] = True
+    )
+    flow.response = http.Response(
+        b"HTTP/1.1",
+        101,
+        reason=b"Switching Protocols",
+        headers=http.Headers(
+            connection='upgrade',
+            upgrade='websocket',
+            sec_websocket_accept=b'',
+        ),
+        content=b'',
+        trailers=None,
+        timestamp_start=946681202,
+        timestamp_end=946681203,
+    )
+    flow.websocket = websocket.WebSocketData()
 
     if messages is True:
-        messages = [
-            websocket.WebSocketMessage(Opcode.BINARY, True, b"hello binary"),
-            websocket.WebSocketMessage(Opcode.TEXT, True, b"hello text"),
-            websocket.WebSocketMessage(Opcode.TEXT, False, b"it's me"),
+        flow.websocket.messages = [
+            websocket.WebSocketMessage(Opcode.BINARY, True, b"hello binary", 946681203),
+            websocket.WebSocketMessage(Opcode.TEXT, True, b"hello text", 946681204),
+            websocket.WebSocketMessage(Opcode.TEXT, False, b"it's me", 946681205),
         ]
-    if err is True:
-        err = terr()
 
-    f.messages = messages
-    f.error = err
-    f.reply = controller.DummyReply()
-    return f
+    flow.websocket.close_reason = close_reason
+
+    if close_code is not None:
+        flow.websocket.close_code = close_code
+    else:
+        if err is True:
+            # ABNORMAL_CLOSURE
+            flow.websocket.close_code = 1006
+        else:
+            # NORMAL_CLOSURE
+            flow.websocket.close_code = 1000
+
+    flow.reply = controller.DummyReply()
+    return flow
 
 
 def tflow(client_conn=True, server_conn=True, req=True, resp=None, err=None):
     """
     @type client_conn: bool | None | mitmproxy.proxy.connection.ClientConnection
     @type server_conn: bool | None | mitmproxy.proxy.connection.ServerConnection
-    @type req:         bool | None | mitmproxy.proxy.protocol.http.HTTPRequest
-    @type resp:        bool | None | mitmproxy.proxy.protocol.http.HTTPResponse
+    @type req:         bool | None | mitmproxy.proxy.protocol.http.Request
+    @type resp:        bool | None | mitmproxy.proxy.protocol.http.Response
     @type err:         bool | None | mitmproxy.proxy.protocol.primitives.Error
     @return:           mitmproxy.proxy.protocol.http.HTTPFlow
     """
@@ -112,9 +105,9 @@ def tflow(client_conn=True, server_conn=True, req=True, resp=None, err=None):
     if server_conn is True:
         server_conn = tserver_conn()
     if req is True:
-        req = tutils.treq()
+        req = treq()
     if resp is True:
-        resp = tutils.tresp()
+        resp = tresp()
     if err is True:
         err = terr()
 
@@ -147,8 +140,8 @@ def tdummyflow(client_conn=True, server_conn=True, err=None):
     return f
 
 
-def tclient_conn() -> compat.Client:
-    c = compat.Client.from_state(dict(
+def tclient_conn() -> connection.Client:
+    c = connection.Client.from_state(dict(
         id=str(uuid.uuid4()),
         address=("127.0.0.1", 22),
         mitmcert=None,
@@ -158,7 +151,7 @@ def tclient_conn() -> compat.Client:
         timestamp_end=946681206,
         sni="address",
         cipher_name="cipher",
-        alpn_proto_negotiated=b"http/1.1",
+        alpn=b"http/1.1",
         tls_version="TLSv1.2",
         tls_extensions=[(0x00, bytes.fromhex("000e00000b6578616d"))],
         state=0,
@@ -169,14 +162,12 @@ def tclient_conn() -> compat.Client:
         alpn_offers=[],
         cipher_list=[],
     ))
-    c.reply = controller.DummyReply()
-    c.rfile = io.BytesIO()
-    c.wfile = io.BytesIO()
+    c.reply = controller.DummyReply()  # type: ignore
     return c
 
 
-def tserver_conn() -> compat.Server:
-    c = compat.Server.from_state(dict(
+def tserver_conn() -> connection.Server:
+    c = connection.Server.from_state(dict(
         id=str(uuid.uuid4()),
         address=("address", 22),
         source_address=("address", 22),
@@ -187,7 +178,7 @@ def tserver_conn() -> compat.Server:
         timestamp_end=946681205,
         tls_established=True,
         sni="address",
-        alpn_proto_negotiated=None,
+        alpn=None,
         tls_version="TLSv1.2",
         via=None,
         state=0,
@@ -199,15 +190,10 @@ def tserver_conn() -> compat.Server:
         cipher_list=[],
         via2=None,
     ))
-    c.reply = controller.DummyReply()
-    c.rfile = io.BytesIO()
-    c.wfile = io.BytesIO()
+    c.reply = controller.DummyReply()  # type: ignore
     return c
 
 
-def terr(content="error"):
-    """
-    @return: mitmproxy.proxy.protocol.primitives.Error
-    """
-    err = flow.Error(content)
+def terr(content: str = "error") -> flow.Error:
+    err = flow.Error(content, 946681207)
     return err
