@@ -42,37 +42,6 @@ console_flowlist_layout = [
 ]
 
 
-class UnsupportedLog:
-    """
-        A small addon to dump info on flow types we don't support yet.
-    """
-
-    def websocket_message(self, f):
-        message = f.messages[-1]
-        ctx.log.info(f.message_info(message))
-        ctx.log.debug(
-            message.content if isinstance(message.content, str) else strutils.bytes_to_escaped_str(message.content))
-
-    def websocket_end(self, f):
-        ctx.log.info("WebSocket connection closed by {}: {} {}, {}".format(
-            f.close_sender,
-            f.close_code,
-            f.close_message,
-            f.close_reason))
-
-    def tcp_message(self, f):
-        message = f.messages[-1]
-        direction = "->" if message.from_client else "<-"
-        ctx.log.info("{client_host}:{client_port} {direction} tcp {direction} {server_host}:{server_port}".format(
-            client_host=f.client_conn.address[0],
-            client_port=f.client_conn.address[1],
-            server_host=f.server_conn.address[0],
-            server_port=f.server_conn.address[1],
-            direction=direction,
-        ))
-        ctx.log.debug(strutils.bytes_to_escaped_str(message.content))
-
-
 class ConsoleAddon:
     """
         An addon that exposes console-specific commands, and hooks into required
@@ -120,13 +89,16 @@ class ConsoleAddon:
             "console_mouse", bool, True,
             "Console mouse interaction."
         )
-
         loader.add_option(
             "console_flowlist_layout",
             str, "default",
             "Set the flowlist layout",
             choices=sorted(console_flowlist_layout)
         )
+        loader.add_option(
+            "console_strip_trailing_newlines", bool, False,
+            "Strip trailing newlines from edited request/response bodies."
+        )
 
     @command.command("console.layout.options")
     def layout_options(self) -> typing.Sequence[str]:
@@ -235,11 +207,11 @@ class ConsoleAddon:
 
     @command.command("console.choose")
     def console_choose(
-            self,
-            prompt: str,
-            choices: typing.Sequence[str],
-            cmd: mitmproxy.types.Cmd,
-            *args: mitmproxy.types.CmdArgs
+        self,
+        prompt: str,
+        choices: typing.Sequence[str],
+        cmd: mitmproxy.types.Cmd,
+        *args: mitmproxy.types.CmdArgs
     ) -> None:
         """
             Prompt the user to choose from a specified list of strings, then
@@ -261,11 +233,11 @@ class ConsoleAddon:
 
     @command.command("console.choose.cmd")
     def console_choose_cmd(
-            self,
-            prompt: str,
-            choicecmd: mitmproxy.types.Cmd,
-            subcmd: mitmproxy.types.Cmd,
-            *args: mitmproxy.types.CmdArgs
+        self,
+        prompt: str,
+        choicecmd: mitmproxy.types.Cmd,
+        subcmd: mitmproxy.types.Cmd,
+        *args: mitmproxy.types.CmdArgs
     ) -> None:
         """
             Prompt the user to choose from a list of strings returned by a
@@ -361,7 +333,7 @@ class ConsoleAddon:
         """
             Spawn an external viewer for a flow request or response body based
             on the detected MIME type. We use the mailcap system to find the
-            correct viewier, and fall back to the programs in $PAGER or $EDITOR
+            correct viewer, and fall back to the programs in $PAGER or $EDITOR
             if necessary.
         """
         fpart = getattr(flow, part, None)
@@ -424,11 +396,11 @@ class ConsoleAddon:
         flow.backup()
 
         require_dummy_response = (
-                flow_part in ("response-headers", "response-body", "set-cookies") and
-                flow.response is None
+            flow_part in ("response-headers", "response-body", "set-cookies") and
+            flow.response is None
         )
         if require_dummy_response:
-            flow.response = http.HTTPResponse.make()
+            flow.response = http.Response.make()
         if flow_part == "cookies":
             self.master.switch_view("edit_focus_cookies")
         elif flow_part == "urlencoded form":
@@ -449,13 +421,14 @@ class ConsoleAddon:
             else:
                 message = flow.response
             c = self.master.spawn_editor(message.get_content(strict=False) or b"")
-            # Fix an issue caused by some editors when editing a
-            # request/response body. Many editors make it hard to save a
-            # file without a terminating newline on the last line. When
-            # editing message bodies, this can cause problems. For now, I
-            # just strip the newlines off the end of the body when we return
-            # from an editor.
-            message.content = c.rstrip(b"\n")
+            # Many editors make it hard to save a file without a terminating
+            # newline on the last line. When editing message bodies, this can
+            # cause problems. We strip trailing newlines by default, but this
+            # behavior is configurable.
+            if self.master.options.console_strip_trailing_newlines:
+                message.content = c.rstrip(b"\n")
+            else:
+                message.content = c
         elif flow_part == "set-cookies":
             self.master.switch_view("edit_focus_setcookies")
         elif flow_part == "url":
@@ -529,7 +502,7 @@ class ConsoleAddon:
                         [strutils.always_str(x) or "" for x in row]  # type: ignore
                     )
             ctx.log.alert("Saved %s rows as CSV." % (len(rows)))
-        except IOError as e:
+        except OSError as e:
             ctx.log.error(str(e))
 
     @command.command("console.grideditor.editor")
@@ -556,7 +529,7 @@ class ConsoleAddon:
         try:
             self.master.commands.call_strings(
                 "view.settings.setval",
-                ["@focus", "flowview_mode_%s" % (idx,), mode]
+                ["@focus", f"flowview_mode_{idx}", mode]
             )
         except exceptions.CommandError as e:
             ctx.log.error(str(e))
@@ -580,7 +553,7 @@ class ConsoleAddon:
 
         return self.master.commands.call_strings(
             "view.settings.getval",
-            ["@focus", "flowview_mode_%s" % (idx,), self.master.options.console_default_contentview]
+            ["@focus", f"flowview_mode_{idx}", self.master.options.console_default_contentview]
         )
 
     @command.command("console.key.contexts")
@@ -592,11 +565,11 @@ class ConsoleAddon:
 
     @command.command("console.key.bind")
     def key_bind(
-            self,
-            contexts: typing.Sequence[str],
-            key: str,
-            cmd: mitmproxy.types.Cmd,
-            *args: mitmproxy.types.CmdArgs
+        self,
+        contexts: typing.Sequence[str],
+        key: str,
+        cmd: mitmproxy.types.Cmd,
+        *args: mitmproxy.types.CmdArgs
     ) -> None:
         """
             Bind a shortcut key.
