@@ -1,9 +1,12 @@
+import codecs
 import os
 import glob
+import re
 import typing
 
 from mitmproxy import exceptions
 from mitmproxy import flow
+from mitmproxy.utils import emoji, strutils
 
 if typing.TYPE_CHECKING:  # pragma: no cover
     from mitmproxy.command import CommandManager
@@ -37,6 +40,10 @@ class Data(typing.Sequence[typing.Sequence[typing.Union[str, bytes]]]):
     pass
 
 
+class Marker(str):
+    pass
+
+
 class Choice:
     def __init__(self, options_command):
         self.options_command = options_command
@@ -99,16 +106,52 @@ class _StrType(_BaseType):
     typ = str
     display = "str"
 
+    # https://docs.python.org/3/reference/lexical_analysis.html#string-and-bytes-literals
+    escape_sequences = re.compile(r"""
+        \\ (
+        [\\'"abfnrtv]  # Standard C escape sequence
+        | [0-7]{1,3}   # Character with octal value
+        | x..          # Character with hex value
+        | N{[^}]+}     # Character name in the Unicode database
+        | u....        # Character with 16-bit hex value
+        | U........    # Character with 32-bit hex value
+        )
+        """, re.VERBOSE)
+
+    @staticmethod
+    def _unescape(match: re.Match) -> str:
+        return codecs.decode(match.group(0), "unicode-escape")  # type: ignore
+
     def completion(self, manager: "CommandManager", t: type, s: str) -> typing.Sequence[str]:
         return []
 
     def parse(self, manager: "CommandManager", t: type, s: str) -> str:
-        return s
+        try:
+            return self.escape_sequences.sub(self._unescape, s)
+        except ValueError as e:
+            raise exceptions.TypeError(f"Invalid str: {e}") from e
 
     def is_valid(self, manager: "CommandManager", typ: typing.Any, val: typing.Any) -> bool:
         return isinstance(val, str)
 
 
+class _BytesType(_BaseType):
+    typ = bytes
+    display = "bytes"
+
+    def completion(self, manager: "CommandManager", t: type, s: str) -> typing.Sequence[str]:
+        return []
+
+    def parse(self, manager: "CommandManager", t: type, s: str) -> bytes:
+        try:
+            return strutils.escaped_str_to_bytes(s)
+        except ValueError as e:
+            raise exceptions.TypeError(str(e))
+
+    def is_valid(self, manager: "CommandManager", typ: typing.Any, val: typing.Any) -> bool:
+        return isinstance(val, bytes)
+
+
 class _UnknownType(_BaseType):
     typ = Unknown
     display = "unknown"
@@ -252,8 +295,8 @@ class _CutSpecType(_BaseType):
         "response.raw_content",
         "response.header[",
 
-        "client_conn.address.port",
-        "client_conn.address.host",
+        "client_conn.peername.port",
+        "client_conn.peername.host",
         "client_conn.tls_version",
         "client_conn.sni",
         "client_conn.tls_established",
@@ -406,6 +449,29 @@ class _ChoiceType(_BaseType):
         return val in opts
 
 
+ALL_MARKERS = ['true', 'false'] + list(emoji.emoji)
+
+
+class _MarkerType(_BaseType):
+    typ = Marker
+    display = "marker"
+
+    def completion(self, manager: "CommandManager", t: Choice, s: str) -> typing.Sequence[str]:
+        return ALL_MARKERS
+
+    def parse(self, manager: "CommandManager", t: Choice, s: str) -> str:
+        if s not in ALL_MARKERS:
+            raise exceptions.TypeError("Invalid choice.")
+        if s == 'true':
+            return ":default:"
+        elif s == 'false':
+            return ""
+        return s
+
+    def is_valid(self, manager: "CommandManager", typ: typing.Any, val: str) -> bool:
+        return val in ALL_MARKERS
+
+
 class TypeManager:
     def __init__(self, *types):
         self.typemap = {}
@@ -428,7 +494,9 @@ CommandTypes = TypeManager(
     _FlowType,
     _FlowsType,
     _IntType,
+    _MarkerType,
     _PathType,
     _StrType,
     _StrSeqType,
+    _BytesType,
 )
